﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.SceneManagement;

public class GameController : MonoBehaviour {

    public Text winText;
    bool gameOver;

    string[] platform2Layout =
    {
        "* *************",
        "* *   *       *",
        "* *   *   *   *",
        "* *   *   *   *",
        "* *********   *",
        "*     *   *   *",
        "*******   *****",
        "      *        ",
        "****  *        ",
        "*  *  *********",
        "*  *       *  *",
        "*  *****   *  *",
        "*  *   *   *  *",
        "*  *   *   *  *",
        "** *   *   *  *",
        " * *   *   *  *",
        " * *** *****  *",
        " *   *        *",
        " *   *  *******",
        " *   ****      "
    };

    RunnerLocator startTile = new RunnerLocator(null, 1, 0, 0); // start tile for ball
    RunnerLocator targetTile = new RunnerLocator(null, 19, 1, 0); // target tile to end game
 
    GameObject platformObject;
    Platform thePlatform;
    RunnerController runnerController; // controller for the ball
    ChaserController chaserController; // controller for the chasers
    CameraRunner cameraRunner; // camera controller

    void Start()
    {
        Time.timeScale = 1; // resume time in case of termination
        gameOver = false;

        platformObject = GameObject.Find("Platform"); // generate the platform
        thePlatform = platformObject.GetComponent<Platform>();
        thePlatform.Generate(new Vector3(0, -0.5f, 0), platformObject, platform2Layout); // drop platform down 0.5 so top of platform is at y = 0

        runnerController = GameObject.Find("Ball Runner").GetComponent<RunnerController>();
        runnerController.Initialize(thePlatform, startTile, targetTile);

        chaserController = GameObject.Find("Chaser").GetComponent<ChaserController>();
        chaserController.Initialize(thePlatform, startTile.Neighbor(2)); // chaser starts just behind start tile

        cameraRunner = GameObject.Find("Main Camera").GetComponent<CameraRunner>();
        cameraRunner.SetCameraAngle(170);
    }

    void Update()
    {
        // Quit anytime using ESC or "Q"
        if (Input.GetKeyDown(KeyCode.Escape) || Input.GetKeyDown(KeyCode.Q))
        {
            Time.timeScale = 1;
            Debug.Log("QUIT button hit");     // for debugging in editor
            Application.Quit();
        }
        // Hit 'R' to restart level
        if (Input.GetKeyDown(KeyCode.R))
        {
            Time.timeScale = 1;
            UnityEngine.SceneManagement.SceneManager.LoadScene("Scene-1");
        }
        // Hit 'P' to pause/unpause game
        if (!gameOver && Input.GetKeyDown(KeyCode.P))
        {
            Time.timeScale = (Time.timeScale > 0 ? 0 : 1); // toggle 1 <--> 0
        }
        // Hit 'Z' to toggle slow-motion
        if (!gameOver && Input.GetKeyDown(KeyCode.Z))
        {
            Time.timeScale = (Time.timeScale == 0.5f ? 1 : 0.5f); // toggle 1 <--> 0.5 
        }
        if (!gameOver && (Input.GetKeyDown(KeyCode.A) || Input.GetKeyDown(KeyCode.LeftArrow)))
        {
            runnerController.RequestTurn(3);
        }
        else if (!gameOver && (Input.GetKeyDown(KeyCode.D) || Input.GetKeyDown(KeyCode.RightArrow)))
        {
            runnerController.RequestTurn(1);
        }
    }

    public void SignalWin()
    {
        winText.text = "Congratulations! You have successfully evaded the dreaded bunny horde!";
        Time.timeScale = 0;
        gameOver = true;
    }

    public void SignalLoss()
    {
        winText.text = "Ack! The cute little bunnies have defeated you!";
        Time.timeScale = 0;
        gameOver = true;
    }
}
