﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Platform : MonoBehaviour {

    int nRows;
    int nCols;
    Vector3 platformOrigin;
    GameObject[,] tiles;

    float tileHeight;
    float tileWidth;

    public void Generate(Vector3 origin, GameObject parent, string[] layout)
    {
        nRows = layout.GetLength(0);
        nCols = layout[0].Length;
        platformOrigin = origin;
        GameObject tile = Resources.Load("Prefabs/PlatformTile") as GameObject;
        Vector3 pieceSize = tile.GetComponent<Renderer>().bounds.size;
        tileHeight = pieceSize.z;
        tileWidth = pieceSize.x;

        tiles = new GameObject[nRows, nCols];
        for (int r = 0; r < nRows; r++)
        {
            for (int c = 0; c < nCols; c++)
            {
                if (layout[r][c] != ' ')
                {
                    Vector3 position = platformOrigin + new Vector3(c * tileWidth, 0, r * tileHeight);
                    tiles[r,c] = Instantiate(tile,
                                        position,
                                        Quaternion.identity,
                                        parent.transform);
                } else
                {
                    tiles[r, c] = null;
                }
            }
        }
    }

    public int NRows
    {
        get { return nRows; }
    }

    public int NCols
    {
        get { return nCols; }
    }

    public Vector3 Origin
    {
        get { return platformOrigin; }
    }

    public Vector3 CenterPoint(int r, int c)
    {
        return platformOrigin + new Vector3(c * tileWidth, 0, r * tileHeight);
    }

    public void MakeTarget(int r, int c)
    {
        if (tiles[r,c] != null)
        {
            tiles[r,c].GetComponent<MeshRenderer>().material.SetColor("_Color", Color.red);
        }
    }

    public int RowIndex(float z)
    {
        return (int) Mathf.Floor((z - platformOrigin.z + tileHeight / 2) / tileHeight);
    }

    public int ColIndex(float x)
    {
        return (int) Mathf.Floor((x - platformOrigin.x + tileWidth / 2) / tileWidth);
    }

    public bool Exists(int r, int c)
    {
        return (r >= 0 && r < nRows && c >= 0 && c < nCols && tiles[r, c] != null);
    }
}
